FormInstructionContent class

Constructors

FormInstructionContent({required String? type, FormText? text, double? space, ImageContent? image})

Properties

hashCode int
The hash code for this object.
no setterinherited
image ImageContent?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
space double?
final
text FormText?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) FormInstructionContent